Coverage for appr/models/kv/etcd/__init__.py: 100%

# Coverage for appr/models/kv/etcd/__init__.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 | import os import etcd class EtcdClient(etcd.client.Client): pass ETCD_HOST = os.getenv("ETCD_HOST", "localhost") etcd_client = EtcdClient(host=ETCD_HOST, port=2379)